@@ -32,11 +32,6 @@ func (o Options) Run() error {
 		o.Options = strings.Split(strings.TrimSpace(input), "\n")
 	}
 
-	var items = make([]item, len(o.Options))
-	for i, option := range o.Options {
-		items[i] = item{text: option, selected: false}
-	}
-
 	// We don't need to display prefixes if we are only picking one option.
 	// Simply displaying the cursor is enough.
 	if o.Limit == 1 && !o.NoLimit {
@@ -51,6 +46,29 @@ func (o Options) Run() error {
 		o.Limit = len(o.Options)
 	}
 
+	// Keep track of the selected items.
+	currentSelected := 0
+	// Check if selected items should be used.
+	hasSelectedItems := len(o.Selected) > 0
+
+	startingIndex := 0
+
+	var items = make([]item, len(o.Options))
+
+	for i, option := range o.Options {
+		// Check if the option should be selected.
+		isSelected := hasSelectedItems && currentSelected < o.Limit && arrayContains(o.Selected, option)
+		// If the option is selected then increment the current selected count.
+		if isSelected {
+			currentSelected++
+			if o.Limit == 1 {
+				startingIndex = i
+			}
+		}
+
+		items[i] = item{text: option, selected: isSelected}
+	}
+
 	// Use the pagination model to display the current and total number of
 	// pages.
 	pager := paginator.New()
@@ -67,6 +85,7 @@ func (o Options) Run() error {
 	pager.UsePgUpPgDownKeys = false
 
 	tm, err := tea.NewProgram(model{
+		index:             startingIndex,
 		height:            o.Height,
 		cursor:            o.Cursor,
 		selectedPrefix:    o.SelectedPrefix,
@@ -78,6 +97,7 @@ func (o Options) Run() error {
 		cursorStyle:       o.CursorStyle.ToLipgloss(),
 		itemStyle:         o.ItemStyle.ToLipgloss(),
 		selectedItemStyle: o.SelectedItemStyle.ToLipgloss(),
+		numSelected:       currentSelected,
 	}, tea.WithOutput(os.Stderr)).StartReturningModel()
 
 	if err != nil {
@@ -108,3 +128,13 @@ func (o Options) BeforeReset(ctx *kong.Context) error {
 	style.HideFlags(ctx)
 	return nil
 }
+
+// Check if an array contains a value.
+func arrayContains(strArray []string, value string) bool {
+	for _, str := range strArray {
+		if str == value {
+			return true
+		}
+	}
+	return false
+}
