@@ -1,10 +1,12 @@
 package confirm
 
 import (
+	"fmt"
 	"os"
 
 	"github.com/alecthomas/kong"
 	tea "github.com/charmbracelet/bubbletea"
+
 	"github.com/charmbracelet/gum/style"
 )
 
@@ -15,6 +17,8 @@ func (o Options) Run() error {
 		affirmative:     o.Affirmative,
 		negative:        o.Negative,
 		confirmation:    o.Default,
+		timeout:         o.Timeout,
+		hasTimeout:      o.Timeout > 0,
 		prompt:          o.Prompt,
 		selectedStyle:   o.SelectedStyle.ToLipgloss(),
 		unselectedStyle: o.UnselectedStyle.ToLipgloss(),
@@ -22,7 +26,7 @@ func (o Options) Run() error {
 	}, tea.WithOutput(os.Stderr)).StartReturningModel()
 
 	if err != nil {
-		return err
+		return fmt.Errorf("unable to run confirm: %w", err)
 	}
 
 	if m.(model).confirmation {
@@ -36,5 +40,6 @@ func (o Options) Run() error {
 
 // BeforeReset hook. Used to unclutter style flags.
 func (o Options) BeforeReset(ctx *kong.Context) error {
-	return style.HideFlags(ctx)
+	style.HideFlags(ctx)
+	return nil
 }
