@@ -7,6 +7,7 @@ import (
 	"github.com/alecthomas/kong"
 	"github.com/charmbracelet/bubbles/textarea"
 	tea "github.com/charmbracelet/bubbletea"
+
 	"github.com/charmbracelet/gum/internal/exit"
 	"github.com/charmbracelet/gum/internal/stdin"
 	"github.com/charmbracelet/gum/style"
@@ -48,16 +49,20 @@ func (o Options) Run() error {
 
 	p := tea.NewProgram(model{textarea: a}, tea.WithOutput(os.Stderr))
 	tm, err := p.StartReturningModel()
+	if err != nil {
+		return fmt.Errorf("failed to run write: %w", err)
+	}
 	m := tm.(model)
 	if m.aborted {
 		return exit.ErrAborted
 	}
 
 	fmt.Println(m.textarea.Value())
-	return err
+	return nil
 }
 
 // BeforeReset hook. Used to unclutter style flags.
 func (o Options) BeforeReset(ctx *kong.Context) error {
-	return style.HideFlags(ctx)
+	style.HideFlags(ctx)
+	return nil
 }
